==> nodejs_interop-0.7.0.tar.gz: lib/src/node/buffer/buffer.dart <==
part of nodejs_interop.node;
// ignore_for_file: avoid_positional_boolean_parameters

/// An octet stream of binary data.
@JS('Buffer')
class Buffer extends Uint8Array {

  /// The number of bytes of an element.
  external static int get BYTES_PER_ELEMENT;

  /// The string value of the constructor name.
  external static String get name;

  /// This is the number of bytes used to determine the size of pre-allocated, internal [Buffer] instances used for pooling.
  /// Defaults to `8192`.
  external static int get poolSize;
  external static set poolSize(int value);

  /// Allocates a new buffer of [size] bytes, pre-filled by [fill] value (an integer, a string or a [Buffer]).
  /// If [fill] is a string, [encoding] specifies its encoding.
  external static Buffer alloc(int size, [fill = 0, String encoding = BufferEncoding.utf8]);

  /// Allocates a new buffer of [size] bytes.
  external static Buffer allocUnsafe(int size);

  /// Allocates a new buffer of [size] bytes.
  external static Buffer allocUnsafeSlow(int size);

  /// Returns the actual byte length of a string [value].
  external static int byteLength(value, [String encoding = BufferEncoding.utf8]);

  /// Returns a new buffer which is the result of concatenating all the [Buffer] or `Uint8List` instances in the [list] together.
  external static Buffer concat(List list, [int totalLength]);

  /// Allocates a new buffer from the specified [value].
  external static Buffer from(value, [arg1, arg2]);

  /// Gets a value indicating whether [object] is a [Buffer].
  external static Buffer isBuffer(object);

  /// Gets a value indicating whether [encoding] contains a supported character encoding.
  external static Buffer isEncoding(String encoding);

  /// The amount of memory allocated for this buffer in bytes.
  /// Note that this does not necessarily reflect the amount of "usable" data.
  @override
  external int get length;

  /// Compares this buffer with [target] and returns an integer indicating whether this buffer comes before, after, or is the same as [target] in sort order.
  /// Comparison is based on the actual sequence of bytes in each buffer.
  external int compare(Buffer target, [int targetStart = 0, int targetEnd, int sourceStart = 0, int sourceEnd]);

  /// Copies data from a region of this buffer to a region in [target] even if the [target] memory region overlaps with this buffer.
  /// Returns the number of bytes copied.
  external int copy(Buffer target, [int targetStart = 0, int sourceStart = 0, int sourceEnd]);

  /// Gets a value indicating whether this buffer and [other] have exactly the same bytes
  external bool equals(Buffer other);

  /// Fills this buffer with the specified [value]. If the `offset` and [end] are not given, the entire buffer will be filled.
  /// If [value] is a string, [encoding] specifies its encoding.
  @override
  external Buffer fill(value, [offsetOrEncoding, int end, String encoding = BufferEncoding.utf8]);

  /// Gets a value indicating whether this buffer includes the specified [value].
  /// If [value] is a string, [encoding] specifies its encoding.
  @override
  external bool includes(value, [byteOffsetOrEncoding, String encoding = BufferEncoding.utf8]);

  /// Returns the first index of [value] in this buffer. If [value] is a string, [encoding] specifies its encoding.
  ///
  /// Searches the buffer from index `byteOffset` to the end of the buffer.
  /// Returns -1 if [value] is not found.
  @override
  external int indexOf(value, [byteOffsetOrEncoding, String encoding = BufferEncoding.utf8]);

  /// Returns the last index of [value] in this buffer. If [value] is a string, [encoding] specifies its encoding.
  ///
  /// Searches the buffer backwards from index `byteOffset` to `0`.
  /// Returns -1 if [value] is not found.
  @override
  external int lastIndexOf(value, [byteOffsetOrEncoding, String encoding = BufferEncoding.utf8]);

  /// Reads a 64-bit double from this buffer at the specified [offset] with big endian format.
  external double readDoubleBE(int offset, [bool noAssert = false]);

  /// Reads a 64-bit double from this buffer at the specified [offset] with little endian format.
  external double readDoubleLE(int offset, [bool noAssert = false]);

  /// Reads a 32-bit float from this buffer at the specified [offset] with big endian format.
  external double readFloatBE(int offset, [bool noAssert = false]);

  /// Reads a 32-bit float from this buffer at the specified [offset] with little endian format.
  external double readFloatLE(int offset, [bool noAssert = false]);

  /// Reads a signed 16-bit integer from this buffer at the specified [offset] with big endian format.
  external int readInt16BE(int offset, [bool noAssert = false]);

  /// Reads a signed 16-bit integer from this buffer at the specified [offset] with little endian format.
  external int readInt16LE(int offset, [bool noAssert = false]);

  /// Reads a signed 32-bit integer from this buffer at the specified [offset] with big endian format.
  external int readInt32BE(int offset, [bool noAssert = false]);

  /// Reads a signed 32-bit integer from this buffer at the specified [offset] with little endian format.
  external int readInt32LE(int offset, [bool noAssert = false]);

  /// Reads a signed 8-bit integer from this buffer at the specified [offset].
  external int readInt8(int offset, [bool noAssert = false]);

  /// Reads [byteLength] number of bytes from this buffer at the specified [offset]
  /// and interprets the result as a big endian signed integer. Supports up to 48 bits of accuracy.
  external int readIntBE(int offset, int byteLength, [bool noAssert = false]);

  /// Reads [byteLength] number of bytes from this buffer at the specified [offset]
  /// and interprets the result as a little endian signed integer. Supports up to 48 bits of accuracy.
  external int readIntLE(int offset, int byteLength, [bool noAssert = false]);

  /// Reads an unsigned 16-bit integer from this buffer at the specified [offset] with big endian format.
  external int readUInt16BE(int offset, [bool noAssert = false]);

  /// Reads an unsigned 16-bit integer from this buffer at the specified [offset] with little endian format.
  external int readUInt16LE(int offset, [bool noAssert = false]);

  /// Reads an unsigned 32-bit integer from this buffer at the specified [offset] with big endian format.
  external int readUInt32BE(int offset, [bool noAssert = false]);

  /// Reads an unsigned 32-bit integer from this buffer at the specified [offset] with little endian format.
  external int readUInt32LE(int offset, [bool noAssert = false]);

  /// Reads an unsigned 8-bit integer from this buffer at the specified [offset].
  external int readUInt8(int offset, [bool noAssert = false]);

  /// Reads [byteLength] number of bytes from this buffer at the specified [offset]
  /// and interprets the result as a big endian unsigned integer. Supports up to 48 bits of accuracy.
  external int readUIntBE(int offset, int byteLength, [bool noAssert = false]);

  /// Reads [byteLength] number of bytes from this buffer at the specified [offset]
  /// and interprets the result as a little endian unsigned integer. Supports up to 48 bits of accuracy.
  external int readUIntLE(int offset, int byteLength, [bool noAssert = false]);

  /// Returns a new buffer that references the same memory as the original, but offset and cropped by the [start] and [end] indices.
  @override
  external Buffer slice([int start = 0, int end]);

  /// Interprets this buffer as a list of unsigned 16-bit integers and swaps the byte-order in-place.
  external Buffer swap16();

  /// Interprets this buffer as a list of unsigned 32-bit integers and swaps the byte-order in-place.
  external Buffer swap32();

  /// Interprets this buffer as a list of 64-bit numbers and swaps the byte-order in-place.
  external Buffer swap64();

  /// Converts this object to a JSON representation.
  external dynamic toJSON();

  /// Decodes this buffer to a string according to the specified character encoding in [encoding].
  /// [start] and [end] may be passed to decode only a subset of this buffer.
  @override
  external String toString([String encoding = BufferEncoding.utf8, int start = 0, int end]);

  /// Writes the specified [string] to this buffer at `offset` according to the character encoding in [encoding].
  /// Returns the number of bytes written.
  ///
  /// The [length] parameter is the number of bytes to write.
  /// If this buffer did not contain enough space to fit the entire [string], only a partial amount of [string] will be written.
  /// However, partially encoded characters will not be written.
  external int write(String string, [offsetOrEncoding, int length, String encoding = BufferEncoding.utf8]);

  /// Writes the specified 64-bit double [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeDoubleBE(double value, int offset, [bool noAssert = false]);

  /// Writes the specified 64-bit double [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeDoubleLE(double value, int offset, [bool noAssert = false]);

  /// Writes the specified 32-bit float [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeFloatBE(double value, int offset, [bool noAssert = false]);

  /// Writes the specified 32-bit float [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeFloatLE(double value, int offset, [bool noAssert = false]);

  /// Writes the specified signed 16-bit integer [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeInt16BE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified signed 16-bit integer [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeInt16LE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified signed 32-bit integer [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeInt32BE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified signed 32-bit integer [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeInt32LE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified signed 8-bit integer [value] to this buffer at the specified [offset].
  /// Returns [offset] plus the number of bytes written.
  external int writeInt8(int value, int offset, [bool noAssert = false]);

  /// Writes [byteLength] bytes of the big endian signed [value] to this buffer at the specified [offset]. Supports up to 48 bits of accuracy.
  /// Returns [offset] plus the number of bytes written.
  external int writeIntBE(int value, int offset, int byteLength, [bool noAssert = false]);

  /// Writes [byteLength] bytes of the little endian signed [value] to this buffer at the specified [offset]. Supports up to 48 bits of accuracy.
  /// Returns [offset] plus the number of bytes written.
  external int writeIntLE(int value, int offset, int byteLength, [bool noAssert = false]);

  /// Writes the specified unsigned 16-bit integer [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeUInt16BE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified unsigned 16-bit integer [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeUInt16LE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified unsigned 32-bit integer [value] to this buffer at the specified [offset] with big endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeUInt32BE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified unsigned 32-bit integer [value] to this buffer at the specified [offset] with little endian format.
  /// Returns [offset] plus the number of bytes written.
  external int writeUInt32LE(int value, int offset, [bool noAssert = false]);

  /// Writes the specified unsigned 8-bit integer [value] to this buffer at the specified [offset].
  /// Returns [offset] plus the number of bytes written.
  external int writeUInt8(int value, int offset, [bool noAssert = false]);

  /// Writes [byteLength] bytes of the big endian unsigned [value] to this buffer at the specified [offset]. Supports up to 48 bits of accuracy.
  /// Returns [offset] plus the number of bytes written.
  external int writeUIntBE(int value, int offset, int byteLength, [bool noAssert = false]);

  /// Writes [byteLength] bytes of the little endian unsigned [value] to this buffer at the specified [offset]. Supports up to 48 bits of accuracy.
  /// Returns [offset] plus the number of bytes written.
  external int writeUIntLE(int value, int offset, int byteLength, [bool noAssert = false]);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/node/buffer/buffer.dart <==
part of nodejs_interop.node;
// ignore_for_file: avoid_classes_with_only_static_members

/// An octet stream of binary data.
@JS('Buffer')
abstract class Buffer {

  /// The number of bytes of an element.
  external static int get BYTES_PER_ELEMENT; // ignore: non_constant_identifier_names

  /// The string value of the constructor name.
  external static String get name;

  /// This is the number of bytes used to determine the size of pre-allocated, internal [Buffer] instances used for pooling.
  /// Defaults to `8192`.
  external static int get poolSize;
  external static set poolSize(int value);

  /// Allocates a new buffer of [size] bytes, pre-filled by [fill] value (an integer, a string or a [Buffer]).
  /// If [fill] is a string, [encoding] specifies its encoding.
  external static Uint8List alloc(int size, [fill = 0, String encoding = BufferEncoding.utf8]);

  /// Allocates a new buffer of [size] bytes.
  external static Uint8List allocUnsafe(int size);

  /// Allocates a new buffer of [size] bytes.
  external static Uint8List allocUnsafeSlow(int size);

  /// Returns the actual byte length of a string [value].
  external static int byteLength(value, [String encoding = BufferEncoding.utf8]);

  /// Compares [buffer1] to [buffer2] and returns a number indicating whether [buffer1] comes before, after, or is the same as [buffer2] in sort order.
  /// Comparison is based on the actual sequence of bytes in each buffer.
  external static int compare(Uint8List buffer1, Uint8List buffer2);

  /// Returns a new buffer which is the result of concatenating all the [Buffer] or `Uint8List` instances in the [list] together.
  external static Uint8List concat(List list, [int totalLength]);

  /// Allocates a new buffer from the specified [value].
  external static Uint8List from(value, [arg1, arg2]);

  /// Gets a value indicating whether [object] is a [Buffer].
  external static bool isBuffer(object);

  /// Gets a value indicating whether [encoding] contains a supported character encoding.
  external static bool isEncoding(String encoding);
}
